@@ -5,9 +5,8 @@ import time
 import boto3
 from halo import Halo
 
-from suite_py.lib.logger import Logger
+from suite_py.lib import logger
 
-logger = Logger()
 
 cloudformation = boto3.client("cloudformation", region_name="eu-west-1")
 cloudfront = boto3.client("cloudfront", region_name="eu-west-1")
