@@ -219,7 +219,7 @@ class GitHandler:
     def is_dirty(self):
         try:
             output = subprocess.run(
-                ["git", "status", "--porcelain"],
+                ["git", "status", "--porcelain", "-uno"],
                 cwd=self._path,
                 check=True,
                 stdout=subprocess.PIPE,
