@@ -5,7 +5,7 @@ from youtrack.connection import Connection
 from youtrack.youtrack import YouTrackException
 
 
-REGEX = r"^([A-Za-z]+-[0-9]+)"
+REGEX = r"([A-Za-z]+-[0-9]+)"
 URL = "https://prima-assicurazioni-spa.myjetbrains.com/youtrack/issue/"
 
 
